arth.div.pie.sepa: Arthropod diversity data for pie chart

arth.div.pie.sepaR Documentation

Arthropod diversity data for pie chart

Description

Dataframe containing proportional abundacne of major orders of arthropod predators from total arthropod abundance on southeastern Pennsylvania farms; used to make pie charts.

Usage

arth.div.pie.sepa

Format

R data.frame

farmName

the general name of 6 individual farms of three "urbanization categories" (high, medium, low)

family

common name of arthropod predator family

meanAbun

mean abundance of arthropod predators in each family across all pitfall traps

prop

proportion of family abundance over the total number of arthropod predators across all pitfall traps at a farm


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.