curacao.exo.herps.sum: Curaçao exotic herps summary data

curacao.exo.herps.sumR Documentation

Curaçao exotic herps summary data

Description

Dataframe summarizing the sites where exotic reptiles and amphibians were observed at Curaçao homeowner sites.

Usage

curacao.exo.herps.sum

Format

R data.frame

species

common name of exotic herp species observed on properties

Site Type

land-use category for the focal property

Percentage of Sites

the number of sites where each herp species was observed in each category


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.