curacao.nat.birds.list: List of Curaçao native birds

curacao.nat.birds.listR Documentation

List of Curaçao native birds

Description

Dataframe with binary presence/absence variable for each bird species found at a Curaçao homeowner site.

Usage

curacao.nat.birds.list

Format

R data.frame

Site

name of the focal property (anonymized by letter here)

sitetype

land-use category for the focal property

Scientific name

number of sites where each herp species was observed in each category

Present

number of sites where each herp species was observed in each category

Common Name

common name of native bird species in Curaçao


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.