curacao.nat.herps.sum: Curaçao native herp summary data

curacao.nat.herps.sumR Documentation

Curaçao native herp summary data

Description

Dataframe summarizing the sites where native reptiles and amphibians were observed at Curaçao homeowner sites.

Usage

curacao.nat.herps.sum

Format

R data.frame

sitetype

land-use category for the focal property

species

common name of native herp species on properties

mean

mean abundance of each native herp species on each property within a land-use category


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.