interact.rich.sepa: Plant community & arthropod richness data

interact.rich.sepaR Documentation

Plant community & arthropod richness data

Description

Dataframe containing arthropod richness and plant community data from southeastern Pennsylvania farms.

Usage

interact.rich.sepa

Format

R data.frame

farmName

the general name of 15 individual farms of three "urbanization categories" (low, medium, high urbanization intensity) and the names of the three categories to plot as comparisons to category means in abundance and richness plots.

richness

richness of arthropod predator families in each pitfall trap on a farm

urbanCat

the urbanization category of each individual farm to be print out in the .html file

weedyCover

the percent ground cover of non-crop plants in a 2-meter radius circle around the pitfall trap


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.