plastic.sepa: Plastic mulch & arthropod richness data

plastic.sepaR Documentation

Plastic mulch & arthropod richness data

Description

Dataframe containing arthropod abundance and richness data from traps based on presence/absence of plastic mulch.

Usage

plastic.sepa

Format

R data.frame

category

factor of pitfall traps placed under plastic mulch ("Plastic) or not under plastic mulch ("No plastic")

meanAbun

mean abundance of arthropod predators in each pitfall trap

meanRich

mean family richness of arthropod predators in each pitfall trap


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.