town: Template data

townR Documentation

Template data

Description

Dataframe containing sample data from a fictitious survey of birds and trees from three towns In this dataset, three parks, all named affectionately after insect groups, in each town were surveyed for ten days.

Usage

town

Format

R data.frame

town

name of town

park

name of park within town

day

day of sampling

num_trees

number of trees sampled in the park

num_birds

number of birds counted in the park on that day


dbturner/c4bi documentation built on March 23, 2022, 6:36 p.m.