| curacao.nat.herps.sum | R Documentation |
Dataframe summarizing the sites where native reptiles and amphibians were observed at Curaçao homeowner sites.
curacao.nat.herps.sum
R data.frame
land-use category for the focal property
common name of native herp species on properties
mean abundance of each native herp species on each property within a land-use category
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.