| plastic.sepa | R Documentation |
Dataframe containing arthropod abundance and richness data from traps based on presence/absence of plastic mulch.
plastic.sepa
R data.frame
factor of pitfall traps placed under plastic mulch ("Plastic) or not under plastic mulch ("No plastic")
mean abundance of arthropod predators in each pitfall trap
mean family richness of arthropod predators in each pitfall trap
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.